@@ -324,6 +324,8 @@ class Database(Connection):
         return [r for r, in rows]
 
     def insert_file_name(self, path, reference_time=None):
+        if reference_time is not None:
+            reference_time = str(reference_time)
         self.cursor.execute("""
             INSERT OR IGNORE INTO file (name, reference)
             VALUES (:path, :reference)
@@ -370,8 +372,8 @@ class Database(Connection):
         """, dict(path=path, variable=variable, pressure=pressure, i=i))
 
     def valid_times(self,
-                    variable=None,
                     pattern=None,
+                    variable=None,
                     initial_time=None):
         """Valid times associated with search criteria"""
         # Note: SQL injection possible if not properly escaped
@@ -410,7 +412,7 @@ class Database(Connection):
         rows = self.cursor.fetchall()
         return [time for time, in rows]
 
-    def pressures(self, variable=None, pattern=None, initial_time=None):
+    def pressures(self, pattern=None, variable=None, initial_time=None):
         """Select pressures from database"""
         # Note: SQL injection possible if not properly escaped
         #       use ? and :name syntax in template
