@@ -17,6 +17,7 @@ from forest.exceptions import FileNotFound
 from bokeh.palettes import GnBu3, OrRd3
 import itertools
 import math
+from forest.gridded_forecast import _to_datetime
 
 
 class RenderGroup(object):
@@ -128,7 +129,7 @@ class View(object):
     def render(self, state):
         """Gets called when a menu button is clicked (or when application state changes)"""
         if state.valid_time is not None:
-            date = dt.datetime.strptime(state.valid_time, '%Y-%m-%d %H:%M:%S')
+            date = _to_datetime(state.valid_time)
             try:
                 (self.source.geojson,
                  self.tail_line_source.data,
